/* Tabela REDUCAOZ: Tabela de Reduo Z */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela
              REDUCAOZ referente ao processo de Fechamento de Cupom */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela Reduo Z que podem influenciar no
             processo de Fechamento de Cupom, utilizando a tabela Geral de Logs de Operaes */
CREATE OR REPLACE TRIGGER LOG_FIS_REDUCAOZ
AFTER DELETE OR INSERT OR UPDATE
ON REDUCAOZ FOR EACH ROW
DECLARE
   V_DSREMOTEADDR VARCHAR2(50);
   V_DSREMOTEHOST VARCHAR2(50);
   V_DSSERVERRDM  VARCHAR2(20);
   V_DSSERVMETHOD VARCHAR2(50);
   V_DSREMOTEOPER VARCHAR2(12);
   V_NMOPERADOR   VARCHAR2(100);
   V_TIPO         VARCHAR2(1);
   V_DESC         VARCHAR2(1000);
   V_CDFILLOGOPER VARCHAR2(4);
   V_ITPESQ       VARCHAR2(40);
   V_DTOPER       DATE;
   V_STATUS       VARCHAR2(10);
BEGIN
   V_TIPO := '0';
   V_DESC := '';
   V_CDFILLOGOPER := '';

   IF DELETING THEN
      IF :OLD.IDSTATUS = 'A' THEN
         IF :OLD.IDLIBERAPROV IS NOT NULL THEN
            V_DESC := V_DESC || ' LiberaAprov=' || :OLD.IDLIBERAPROV;
         END IF;
         IF :OLD.IDTPAPROV IS NOT NULL THEN
            V_DESC := V_DESC || ' TipoAprov=' || :OLD.IDTPAPROV;
         END IF;
      END IF;

      V_TIPO   := '3';
      V_ITPESQ := :OLD.CDFILIAL||:OLD.CDCAIXA||TO_CHAR(:OLD.DTREDUCAOZ,'DDMMYYYY');
   ELSE
      IF (:OLD.IDSTATUS = 'A' OR NVL(:OLD.IDSTATUS,'!') <> NVL(:NEW.IDSTATUS,'!')) THEN
         IF UPDATING THEN
            IF NVL(:NEW.IDSTATUS,     '!') <> NVL(:OLD.IDSTATUS,     '!') OR
               NVL(:NEW.IDLIBERAPROV, '!') <> NVL(:OLD.IDLIBERAPROV, '!') OR
               NVL(:NEW.IDTPAPROV,    '!') <> NVL(:OLD.IDTPAPROV,    '!') THEN
               V_TIPO   := '2';
               V_ITPESQ := :OLD.CDFILIAL||:OLD.CDCAIXA||TO_CHAR(:OLD.DTREDUCAOZ,'DDMMYYYY');
            END IF;
         ELSE
            V_TIPO   := '1';
            V_ITPESQ := :NEW.CDFILIAL||:NEW.CDCAIXA||TO_CHAR(:NEW.DTREDUCAOZ,'DDMMYYYY');
         END IF;

         IF NVL(:NEW.IDSTATUS, '!') <> NVL(:OLD.IDSTATUS, '!') THEN
            V_DESC := V_DESC || ' StatusAprov=' || :NEW.IDSTATUS;
         END IF;
         IF NVL(:NEW.IDLIBERAPROV, '!') <> NVL(:OLD.IDLIBERAPROV, '!') THEN
            V_DESC := V_DESC || ' LiberaAprov=' || :NEW.IDLIBERAPROV;
         END IF;
         IF NVL(:NEW.IDTPAPROV, '!') <> NVL(:OLD.IDTPAPROV, '!') THEN
            V_DESC := V_DESC || ' TipoAprov=' || :OLD.IDTPAPROV;
         END IF;
      END IF;
   END IF;

   IF  V_TIPO <> '0' THEN
       NMUSUARIO(V_NMOPERADOR);
       WEBTUNNING(V_DSREMOTEADDR,
                  V_DSREMOTEHOST,
                  V_DSSERVERRDM,
                  V_DSSERVMETHOD,
                  V_DSREMOTEOPER);

       IF NOT V_DESC IS NULL THEN
         IF NOT V_NMOPERADOR IS NULL THEN
            V_DTOPER := SYSDATE;
            INSERT INTO LOGOPERA
               (NMTABELA,     DTOPERACAO,   NMRESPOPER,   IDTIPOOPER,  CDPESQITEM,  DSOPERACAO,
                CDFILLOGOPER, DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER,CDORESPOPER)
            VALUES
               ('REDUCAOZ',   V_DTOPER,      V_NMOPERADOR,   V_TIPO,         V_ITPESQ,       SUBSTR(V_DESC,1,400),
                V_CDFILLOGOPER, V_DSSERVERRDM, V_DSREMOTEADDR, V_DSREMOTEHOST, V_DSSERVMETHOD, V_DSREMOTEOPER);
         END IF;
       END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LOG_FIS_REDUCAOZ','6.06.000'); END;
/
